#!/usr/bin/env python
import os

from smtplib import SMTP
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart

from jinja2 import Environment

DEFAULT_TEMPLATE=os.path.dirname(os.path.abspath(__file__))+'/generic.jinja2'

def send(subject, users, data={}, template=DEFAULT_TEMPLATE):
    """
    Send mail to user, admin

    
    :param subject: string, Email Subject
    :param users: List of users mail addresses
    :param data: Dictionary with key/value items for jinja2 template
    :param template: Path to template to render (default to use generic.jinja2)

    Additional information.
    -----------------------

    Example: cvl_mail.send("subject", ("manager@example.com","admin@example.com"), { 'body':'body', 'sender':'server@int.example.com' } )
    """

    file = open(template, 'r')
    template = file.read()

    rt = Environment().from_string(template).render(**data)
    msg = MIMEText(rt, 'html')

    msg['Subject'] = subject
    msg.preamble = 'Preamble'
    FROM = "root"
    msg['From'] = FROM

    server = SMTP('localhost')

    for user in users:
        server.sendmail(FROM, [user], msg.as_string())

    server.quit()



from setuptools import setup
import os,sys

# Following Lapin example
# https://bitbucket.org/CVisionLab/cvl-python/src/51308c1155a6242fbb914870732187adfc8881f0/setup.py?at=default&fileviewer=file-view-default

root_pkg = 'cvlops'

# find all subpackages
root = os.path.join(os.path.dirname(__file__), root_pkg)

packages = []
for subdir, _, _ in os.walk(root):
        subpath = subdir[len(root):].replace(os.path.sep, '.')
        packages.append(root_pkg + subpath)

setup(
    name=root_pkg,
    description='CVISIONLAB OPS Python Utils',
    long_description=open('README.txt').read(),
    version='1.14',
    author='Skubriev Vladimir',
    author_email='skubriev@cvisionlab.com',
    license='GPL',
    url='https://github.com/cvisionlabops/cvlops-python',
    install_requires=[
                  'jinja2'
    ],
    packages=packages,
    package_data={'cvlops': ['jinja2/*.jinja2']},
    #data_files=[('jinja2',['jinja2'])],
    include_package_data=True
)
